These are workflows for performing the analyses included in the manuscript on the pipeline. 

The filter path will need to be updated on your machine to point to the correct filter. 

The qaqc filter can be found here: examples/filters/qaqc_drop.json